==> pmb8.0.1.18.zip: pmb/tables/opac_db_param.model.php <==
<?php
// +-------------------------------------------------+
//  2002-2004 PMB Services / www.sigb.net pmb@sigb.net et contributeurs (voir www.sigb.net)
// +-------------------------------------------------+
// $Id: opac_db_param.model.php,v 1.2 2023/04/07 14:25:37 dbellamy Exp $
// paramtres d'accs  la base MySQL

// prevents direct script access
if(preg_match('/opac_db_param\.inc\.php/', $_SERVER['REQUEST_URI'])) {
	include('./forbidden.inc.php');
	forbidden();
}

// inclure ici les tableaux des bases de donnes accessibles
$_tableau_databases[0]="!!DB_NAME!!";
$_libelle_databases[0]="!!DB_LABEL!!";

// pour multi-bases
if ( empty($database) ) {
    if ( !empty($_COOKIE["PhpMyBibli-OPACDB"]) ) {
        $database = $_COOKIE["PhpMyBibli-OPACDB"];
    } elseif ( !empty($_COOKIE["PhpMyBibli-DATABASE"]) ) {
        $database = $_COOKIE["PhpMyBibli-DATABASE"];
    } else {
        $database = $_tableau_databases[0];
    }
}
if ( !in_array($database, $_tableau_databases) ) {
    $database = $_tableau_databases[0];
}
define('LOCATION', $database) ;

$expiration = time() + 30000000; /* 1 year */
pmb_setcookie ('PhpMyBibli-OPACDB', $database, $expiration);

// define pour les paramtres de connection. A adapter.
switch(LOCATION) {

    default :
    case '!!DB_NAME!!' :
        define('SQL_SERVER', '!!DB_HOST!!');       // nom du serveur
        define('USER_NAME', '!!DB_USER!!');        // nom utilisateur
        define('USER_PASS', '!!DB_PASSWORD!!');    // mot de passe
        define('DATA_BASE', '!!DB_NAME!!');        // nom base de donnes
        define('SQL_TYPE', 'mysql');               // Type de serveur de base de donnes

        // $charset = 'utf-8'; || $charset = 'iso-8859-1';
        // $time_zone = 'Europe/Paris'; //Pour modifier l'heure PHP
        // $time_zone_mysql = "'-00:00'"; //Pour modifier l'heure MySQL
        // $SQL_VARIABLES = 'sql_mode="NO_AUTOCREATE_USER",join_buffer_size=1000000';

        $charset = "!!CHARSET!!";
		/* SQL_VARIABLES */

        break;

}

$dsn_pear = SQL_TYPE."://".USER_NAME.":".USER_PASS."@".SQL_SERVER."/".DATA_BASE ;

==> pmb8.0.1.27.zip: pmb/tables/opac_db_param.model.php <==
<?php
// +-------------------------------------------------+
//  2002-2004 PMB Services / www.sigb.net pmb@sigb.net et contributeurs (voir www.sigb.net)
// +-------------------------------------------------+
// $Id: opac_db_param.model.php,v 1.2.4.1 2026/01/22 15:35:04 dbellamy Exp $
// paramtres d'accs  la base MySQL

// prevents direct script access
if(preg_match('/opac_db_param\.inc\.php/', $_SERVER['REQUEST_URI'])) {
	include('./forbidden.inc.php');
	forbidden();
}

// inclure ici les tableaux des bases de donnes accessibles
$_tableau_databases[0]="!!DB_NAME!!";
$_libelle_databases[0]="!!DB_LABEL!!";

// pour multi-bases
if ( empty($database) ) {
    if ( !empty($_COOKIE["PhpMyBibli-OPACDB"]) ) {
        $database = $_COOKIE["PhpMyBibli-OPACDB"];
    } elseif ( !empty($_COOKIE["PhpMyBibli-DATABASE"]) ) {
        $database = $_COOKIE["PhpMyBibli-DATABASE"];
    } else {
        $database = $_tableau_databases[0];
    }
}
if ( !in_array($database, $_tableau_databases) ) {
    $database = $_tableau_databases[0];
}
define('LOCATION', $database) ;

$expiration = time() + 30000000; /* 1 year */
pmb_setcookie ('PhpMyBibli-OPACDB', $database, $expiration);

// define pour les paramtres de connection. A adapter.
switch(LOCATION) {

    default :
    case '!!DB_NAME!!' :

        // nom du serveur
        define('SQL_SERVER', '!!DB_HOST!!');
        // nom utilisateur (Chiffrement possible avec le module Crypto)
        define('USER_NAME', '!!DB_USER!!');
        // mot de passe (Chiffrement possible avec le module Crypto)
        define('USER_PASS', '!!DB_PASSWORD!!');
        // nom base de donnes
        define('DATA_BASE', '!!DB_NAME!!');
        // Type de serveur de base de donnes
        define('SQL_TYPE', 'mysql');

        // $charset = 'utf-8'; || $charset = 'iso-8859-1';
        // $time_zone = 'Europe/Paris'; //Pour modifier l'heure PHP
        // $time_zone_mysql = "'-00:00'"; //Pour modifier l'heure MySQL
        // $SQL_VARIABLES = 'sql_mode="NO_AUTOCREATE_USER",join_buffer_size=1000000';

        $charset = "!!CHARSET!!";
		/* SQL_VARIABLES */

        break;

}

$dsn_pear = SQL_TYPE."://".USER_NAME.":".USER_PASS."@".SQL_SERVER."/".DATA_BASE ;
